package com.ruoyi.web.controller.api;

import com.ruoyi.common.annotation.Log;
import com.ruoyi.common.core.controller.BaseController;
import com.ruoyi.common.core.domain.AjaxResult;
import com.ruoyi.system.domain.*;
import com.ruoyi.system.domain.req.TRecordResultReq;
import com.ruoyi.system.service.*;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.*;

import javax.annotation.Resource;
import java.util.List;

/**
 * @author zhangcl
 * @date 2022/8/5 17:42
 */
@Api("app接口")
@RestController
@RequestMapping("/api/app")
public class AppController extends BaseController
{
    @Autowired
    private ITRecordService tRecordService;

    @Autowired
    private ITHospitalService tHospitalService;

    @Resource
    private ITDoctorService tDoctorService;

    @Resource
    private ITPatientService tPatientService;

    @Resource
    private ITPatientHospitalDoctorService itPatientHospitalDoctorService;

    @Resource
    private ISysConfigService configService;


    /**
     * 完成AI诊断
     */
    @ApiOperation("完成AI诊断")
    @GetMapping("/ai/finish")
    public AjaxResult finish(Long id)
    {
        TRecord record = tRecordService.selectTRecordById(id);
        if (record != null)
        {
            record.setStatus("1");
        }
        return toAjax(tRecordService.updateTRecord(record));

    }

    @GetMapping("/hospital/list")
    public AjaxResult hospitalList() {
        List<THospital> tHospitals = tHospitalService.selectTHospitalList(new THospital());
        return AjaxResult.success(tHospitals);
    }


    /**
     * 医生信息获取
     *
     * @param doctorId 医生id
     * @return {@code AjaxResult}
     */
    @ApiOperation("医生信息获取")
    @GetMapping("/doctorInformation")
    public AjaxResult doctorInformation(Long doctorId)
    {
        TDoctor tDoctor = tDoctorService.selectTDoctorById(doctorId);
        return AjaxResult.success(tDoctor);
    }

    /**
     * 病人预约
     *
     * @param tPatientHospitalDoctor tPatientHospitalDoctor
     * @return {@code AjaxResult}
     */
    @ApiOperation("患者预约")
    @GetMapping("/patientsToMakeAnAppointment")
    public AjaxResult patientsToMakeAnAppointment(TPatientHospitalDoctor tPatientHospitalDoctor)
    {
        // 患者预约，新增t_record中的一条记录;判断关联表是否存在当前关系
        TRecord tRecord = new TRecord();
        tRecord.setHospitalId(tPatientHospitalDoctor.getHospitalId());
        tRecord.setPatientId(tPatientHospitalDoctor.getPatientId());
        tRecord.setDoctorId(tPatientHospitalDoctor.getDoctorId());
        tRecord.setStatus("0");
        tRecord.setCreateBy(getUsername());
        tRecordService.insertTRecord(tRecord);
        List<TPatientHospitalDoctor> tPHDs = itPatientHospitalDoctorService.selectTPatientHospitalDoctorList(tPatientHospitalDoctor);
        if (tPHDs.isEmpty())
        {
            itPatientHospitalDoctorService.insertTPatientHospitalDoctor(tPatientHospitalDoctor);
        }
        return AjaxResult.success();
    }

    @PutMapping("updateStatus/{id}")
    @Log(title = "修改患者记录至已诊状态")
    public AjaxResult updateStatus(@PathVariable("id") Long id){
        if(id == null){
            return AjaxResult.error("未获取到记录id");
        }
        TRecord tRecord = new TRecord();
        tRecord.setId(id);
        tRecord.setStatus("1");
        tRecordService.updateTRecord(tRecord);
        return AjaxResult.success("更新状态成功",null);
    }

    @GetMapping(value = "/configKey/{configKey}")
    @Log(title = "获取AI结果刷新时间接口")
    public AjaxResult getConfigKey(@PathVariable String configKey)
    {
        return AjaxResult.success(configService.selectConfigByKey(configKey));
    }

    /**
     * 诊断记录上传
     *
     * @return {@code AjaxResult}
     */
    @ApiOperation("诊断记录上传")
    @PostMapping("/diagnosticRecordsUploaded")
    public AjaxResult diagnosticRecordsUploaded(TRecord tRecord) {
        return AjaxResult.success(tRecordService.updateTRecord(tRecord));
    }

    /**
     * 添加病人
     *
     * @param tPatient t病人
     * @return {@code AjaxResult}
     */
    @ApiOperation("添加患者")
    @PostMapping("/addPatient")
    public AjaxResult addPatient(TPatient tPatient) {
        return AjaxResult.success(tPatientService.insertTPatient(tPatient));
    }


    /**
     * 诊断记录列表
     *
     * @param tPatientHospitalDoctor t病人医院医生
     * @return {@code AjaxResult}
     */
    @ApiOperation("诊断记录列表")
    @GetMapping("/diagnosisOfRecordList")
    public AjaxResult diagnosisOfRecordList(TPatientHospitalDoctor tPatientHospitalDoctor) {
        List<TRecord> tRecords = tRecordService.queryRecordListByPHDids(tPatientHospitalDoctor);
        return AjaxResult.success(tRecords);
    }

    /**
     * 患者诊断记录信息细节
     *
     * @param id id
     * @return {@code AjaxResult}
     */
    @ApiOperation("患者诊断记录信息详情")
    @GetMapping("/diagnosisOfRecordDetails")
    public AjaxResult patientsWithDiagnosisOfRecordInformationDetails(Long id) {
        return AjaxResult.success(tRecordService.selectById(id));
    }


    /**
     * 患者已诊列表
     *
     * @param recordResultReq 记录结果要求
     * @return {@code AjaxResult}
     */
    @ApiOperation("患者已诊列表")
    @GetMapping("/patientsDiagnosedList")
    public AjaxResult patientsDiagnosedList(TRecordResultReq recordResultReq) {
        recordResultReq.setStatus("0");
        return AjaxResult.success(tRecordService.selectTRecordListWithoutResult(recordResultReq));
    }


    /**
     * 病人等待名单
     *
     * @param recordResultReq 记录结果要求
     * @return {@code AjaxResult}
     */
    @ApiOperation("患者候诊列表")
    @GetMapping("/patientsWaitingList")
    public AjaxResult patientsWaitingList(TRecordResultReq recordResultReq) {
        recordResultReq.setStatus("2");
        return AjaxResult.success(tRecordService.selectTRecordListWithoutResult(recordResultReq));
    }
}
