package com.ruoyi.system.service.impl;

import java.util.List;
import com.ruoyi.common.utils.DateUtils;
import com.ruoyi.system.domain.TPatientHospitalDoctor;
import com.ruoyi.system.domain.req.TRecordResultReq;
import com.ruoyi.system.domain.resp.TRecordResp;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import com.ruoyi.system.mapper.TRecordMapper;
import com.ruoyi.system.domain.TRecord;
import com.ruoyi.system.service.ITRecordService;

/**
 * 诊断记录信息Service业务层处理
 *
 * @author ruoyi
 * @date 2022-08-03
 */
@Service
public class TRecordServiceImpl implements ITRecordService
{
    @Autowired
    private TRecordMapper tRecordMapper;

    /**
     * 查询诊断记录信息
     *
     * @param id 诊断记录信息主键
     * @return 诊断记录信息
     */
    @Override
    public TRecord selectTRecordById(Long id)
    {
        return tRecordMapper.selectTRecordById(id);
    }

    /**
     * 查询诊断记录信息列表
     *
     * @param tRecord 诊断记录信息
     * @return 诊断记录信息
     */
    @Override
    public List<TRecord> selectTRecordList(TRecord tRecord)
    {
        return tRecordMapper.selectTRecordList(tRecord);
    }

    /**
     * 新增诊断记录信息
     *
     * @param tRecord 诊断记录信息
     * @return 结果
     */
    @Override
    public int insertTRecord(TRecord tRecord)
    {
        tRecord.setCreateTime(DateUtils.getNowDate());
        return tRecordMapper.insertTRecord(tRecord);
    }

    /**
     * 修改诊断记录信息
     *
     * @param tRecord 诊断记录信息
     * @return 结果
     */
    @Override
    public int updateTRecord(TRecord tRecord)
    {
        tRecord.setUpdateTime(DateUtils.getNowDate());
        return tRecordMapper.updateTRecord(tRecord);
    }

    /**
     * 批量删除诊断记录信息
     *
     * @param ids 需要删除的诊断记录信息主键
     * @return 结果
     */
    @Override
    public int deleteTRecordByIds(Long[] ids)
    {
        return tRecordMapper.deleteTRecordByIds(ids);
    }

    /**
     * 删除诊断记录信息信息
     *
     * @param id 诊断记录信息主键
     * @return 结果
     */
    @Override
    public int deleteTRecordById(Long id)
    {
        return tRecordMapper.deleteTRecordById(id);
    }

    @Override
    public List<TRecordResp> selectTRecordListWithoutResult(TRecordResultReq tRecord)
    {
        return tRecordMapper.selectTRecordListWithoutResult(tRecord);
    }

    @Override
    public TRecordResp selectById(Long id)
    {
        return tRecordMapper.selectById(id);
    }

    @Override
    public List<TRecord> queryRecordListByPHDids(TPatientHospitalDoctor tPatientHospitalDoctor)
    {
        return tRecordMapper.queryRecordListByPHDids(tPatientHospitalDoctor);
    }
}
